

import QtQuick 2.0
import QtQuick.Layouts 1.1

Item {
    id: root

//BEGIN Properties
    property Component compactRepresentation
    property Component fullRepresentation
    property Component preferredRepresentation: compactRepresentation
    property int switchWidth: -1
    property int switchHeight: -1
//END Properties


//BEGIN Size hints
    Layout.minimumWidth: internal.currentRepresentationItem && internal.currentRepresentationItem.Layout ? internal.currentRepresentationItem.Layout.minimumWidth : -1
    Layout.minimumHeight: internal.currentRepresentationItem && internal.currentRepresentationItem.Layout ? internal.currentRepresentationItem.Layout.minimumHeight : -1

    Layout.preferredWidth: internal.currentRepresentationItem && internal.currentRepresentationItem.Layout ? internal.currentRepresentationItem.Layout.preferredWidth : -1
    Layout.preferredHeight: internal.currentRepresentationItem && internal.currentRepresentationItem.Layout ? internal.currentRepresentationItem.Layout.preferredHeight : -1

    Layout.maximumWidth: internal.currentRepresentationItem && internal.currentRepresentationItem.Layout ? internal.currentRepresentationItem.Layout.maximumWidth : -1
    Layout.maximumHeight: internal.currentRepresentationItem && internal.currentRepresentationItem.Layout ? internal.currentRepresentationItem.Layout.maximumHeight : -1

    Layout.fillWidth: internal.currentRepresentationItem && internal.currentRepresentationItem.Layout ? internal.currentRepresentationItem.Layout.fillWidth : false
    Layout.fillHeight: internal.currentRepresentationItem && internal.currentRepresentationItem.Layout ? internal.currentRepresentationItem.Layout.fillHeight : false
//END Size hints

//BEGIN Signal handlers
    onWidthChanged: representationTimer.restart()
    onHeightChanged: representationTimer.restart()
//END Signal handlers

//BEGIN internals
    QtObject {
        id: internal
        property Item currentRepresentationItem
        property Item compactRepresentationItem
        property Item fullRepresentationItem
    }

    Timer {
        id: representationTimer
        interval: 250
        onTriggered: {
            var full = false;

            if (switchWidth > 0 && switchHeight > 0) {
                full = root.width > switchWidth && root.height > switchHeight
            } else {
                full = preferredRepresentation == fullRepresentation
            }

            if (full) {
                if (!internal.fullRepresentationItem) {
                    internal.fullRepresentationItem = fullRepresentation.createObject(root);
                }
                internal.currentRepresentationItem = internal.fullRepresentationItem;
                internal.compactRepresentationItem.destroy();
            } else {
                if (!internal.compactRepresentationItem) {
                    internal.compactRepresentationItem = compactRepresentation.createObject(root);
                }
                internal.currentRepresentationItem = internal.compactRepresentationItem;

                if (internal.fullRepresentationItem) {
                    internal.fullRepresentationItem.anchors.left = undefined;
                    internal.fullRepresentationItem.anchors.top = undefined;
                    internal.fullRepresentationItem.anchors.right = undefined;
                    internal.fullRepresentationItem.anchors.bottom = undefined;
                    internal.fullRepresentationItem.visible = false;
                }
            }
            internal.currentRepresentationItem.visible = true;
            internal.currentRepresentationItem.parent = root;
            internal.currentRepresentationItem.anchors.fill = root;
        }
    }
//END internals
}
